/*
 * $Id: Driver.java,v 1.3 2002/07/12 22:56:13 Bear Exp $
 *
 * Copyright 2002 Kohsuke Kawaguchi, Inc. All Rights Reserved.
 * 
 * Use is subject to license terms.
 */
package org.kohsuke.jarv.xerces;
import java.io.File;

import org.iso_relax.verifier.*;
import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXParseException;

/**
 * Test program
 * 
 * @author Kohsuke Kawaguchi (kk@kohsuke.org)
 */
public class Driver {
    public static void main( String[] args ) throws Exception {
        
        // create an instance of VerifierFactory
        // by specifying the schema language.
//        VerifierFactory vf = new XercesVerifierFactory();
        VerifierFactory vf = VerifierFactory.newInstance("http://www.w3.org/2001/XMLSchema");
        System.out.println("Using "+vf.getClass().getName());
        
        // compile a schema. this will find any error in the schema.
        Schema s = vf.compileSchema(new File(args[0]));
        if(s==null) {
            System.out.println("failed to compile a schema");
            return;
        }
        
        // prepare for the validation
        Verifier v = s.newVerifier();
        v.setErrorHandler(new PrintErrorHandler());
        
        try {
            for( int i=1; i<args.length; i++ ) {
                System.out.println("validating "+args[i]);
                if(v.verify(new File(args[i])))
                    System.out.println("valid");
                else
                    System.out.println("invalid");
            }
        } catch( SAXParseException e ) {
            e.printStackTrace();
            if(e.getException()!=null)
                e.getException().printStackTrace();
            throw e;
        }
    }
    
    private static class PrintErrorHandler implements ErrorHandler
    {
        public void fatalError( SAXParseException e ) { print("F",e); }
        public void error( SAXParseException e )      { print("E",e); }
        public void warning( SAXParseException e )    { print("W",e); }
        
        private void print( String category, SAXParseException e ) {
            System.out.println("["+category+"] "+e.getMessage());
        }
    }
}
